@@ -91,7 +91,7 @@ struct Spec<'a> {
 
 impl<'a> Spec<'a> {
     pub fn new(spec: &'a str) -> Self {
-        Spec{ spec: spec, test_n: 0 }
+        Spec{ spec, test_n: 0 }
     }
 }
 
@@ -103,7 +103,7 @@ struct TestCase<'a> {
 
 impl<'a> TestCase<'a> {
     pub fn new(n: usize, input: &'a str, expected: &'a str) -> Self {
-        TestCase { n: n, input: input, expected: expected }
+        TestCase { n, input, expected }
     }
 }
 
@@ -206,6 +206,8 @@ pub fn main() {
     opts.optflag("e", "events", "print event sequence instead of rendering");
     opts.optflag("T", "enable-tables", "enable GitHub-style tables");
     opts.optflag("F", "enable-footnotes", "enable Hoedown-style footnotes");
+    opts.optflag("S", "enable-strikethrough", "enable GitHub-style strikethrough");
+    opts.optflag("L", "enable-tasklists", "enable GitHub-style task lists");
     opts.optopt("s", "spec", "run tests from spec file", "FILE");
     opts.optopt("b", "bench", "run benchmark", "FILE");
     let matches = match opts.parse(&args[1..]) {
@@ -235,6 +237,12 @@ pub fn main() {
     if matches.opt_present("enable-footnotes") {
         opts.insert(Options::ENABLE_FOOTNOTES);
     }
+    if matches.opt_present("enable-strikethrough") {
+        opts.insert(Options::ENABLE_STRIKETHROUGH);
+    }
+    if matches.opt_present("enable-tasklists") {
+        opts.insert(Options::ENABLE_TASKLISTS);
+    }
     if let Some(filename) = matches.opt_str("spec") {
         run_spec(&read_file(&filename).replace("→", "\t"), &matches.free, opts);
     } else if let Some(filename) = matches.opt_str("bench") {
