@@ -28,13 +28,18 @@ use crate::parse::Alignment;
 use crate::strings::CowStr;
 pub use crate::puncttable::{is_ascii_punctuation, is_punctuation};
 
+use memchr::memchr;
+
 // sorted for binary search
-const HTML_TAGS: [&'static str; 47] = ["article", "aside", "blockquote",
-    "body", "button", "canvas", "caption", "col", "colgroup", "dd", "div",
-    "dl", "dt", "embed", "fieldset", "figcaption", "figure", "footer", "form",
-    "h1", "h2", "h3", "h4", "h5", "h6", "header", "hgroup", "hr", "iframe",
-    "li", "map", "object", "ol", "output", "p", "progress","section", "table",
-    "tbody", "td", "textarea", "tfoot", "th", "thead", "tr", "ul", "video"];
+const HTML_TAGS: [&str; 62] = ["address", "article", "aside", "base",
+    "basefont", "blockquote", "body", "caption", "center", "col", "colgroup",
+    "dd", "details", "dialog", "dir", "div", "dl", "dt", "fieldset",
+    "figcaption", "figure", "footer", "form", "frame", "frameset", "h1",
+    "h2", "h3", "h4", "h5", "h6", "head", "header", "hr", "html", "iframe",
+    "legend", "li", "link", "main", "menu", "menuitem", "nav", "noframes",
+    "ol", "optgroup", "option", "p", "param", "section", "source", "summary",
+    "table", "tbody", "td", "tfoot", "th", "thead", "title", "tr", "track",
+    "ul"];
 
 /// Analysis of the beginning of a line, including indentation and container
 /// markers.
@@ -106,7 +111,7 @@ impl<'a> LineStart<'a> {
     }
 
     /// Determine whether we're at end of line (includes end of file).
-    pub fn is_at_eol(&mut self) -> bool {
+    pub fn is_at_eol(&self) -> bool {
         if self.ix == self.text.len() {
             return true;
         }
@@ -157,12 +162,12 @@ impl<'a> LineStart<'a> {
             } else if c >= b'0' && c <= b'9' {
                 let start_ix = self.ix;
                 let mut ix = self.ix + 1;
-                let mut val = (c - b'0') as u64;
+                let mut val = u64::from(c - b'0');
                 while ix < self.text.len() && ix - start_ix < 10 {
                     let c = self.text.as_bytes()[ix];
                     ix += 1;
                     if c >= b'0' && c <= b'9' {
-                        val = val * 10 + (c - b'0') as u64;
+                        val = val * 10 + u64::from(c - b'0');
                     } else if c == b')' || c == b'.' {
                         self.ix = ix;
                         let val_usize = val as usize;
@@ -199,6 +204,41 @@ impl<'a> LineStart<'a> {
         Some((c, start, indent))
     }
 
+    /// Returns Some(is_checked) when a task list marker was found. Resets itself
+    /// to original state otherwise.
+    pub(crate) fn scan_task_list_marker(&mut self) -> Option<bool> {
+        let save = self.clone();
+        self.scan_space_upto(3);
+
+        if !self.scan_ch(b'[') {
+            *self = save;
+            return None;
+        }
+        let is_checked = match self.text[self.ix..].chars().next() {
+            Some(c) if c.is_whitespace() => {
+                self.ix += c.len_utf8();
+                false
+            }
+            Some('x') | Some('X') => {
+                self.ix += 1;
+                true
+            }
+            _ => {
+                *self = save;
+                return None;
+            }
+        };
+        if !self.scan_ch(b']') {
+            *self = save;
+            return None;
+        }
+        if !self.text[self.ix..].chars().next().map(char::is_whitespace).unwrap_or(false) {
+            *self = save;
+            return None;
+        }
+        Some(is_checked)
+    }
+
     pub fn bytes_scanned(&self) -> usize {
         self.ix
     }
@@ -299,10 +339,7 @@ pub fn scan_blank_line(text: &str) -> Option<usize> {
 }
 
 pub fn scan_nextline(s: &str) -> usize {
-    match s.as_bytes().iter().position(|&c| c == b'\n') {
-        Some(x) => x + 1,
-        None => s.len()
-    }
+    memchr(b'\n', s.as_bytes()).map(|x| x + 1).unwrap_or(s.len())
 }
 
 // return: end byte for closing code fence, or None
@@ -315,8 +352,7 @@ pub fn scan_closing_code_fence(text: &str, fence_char: u8, n_fence_char: usize)
     i += num_fence_chars_found;
     let num_trailing_spaces = scan_ch_repeat(&text[i..], b' ');
     i += num_trailing_spaces;
-    if scan_eol(&text[i..]).1 { return Some(i); }
-    return None;
+    if scan_eol(&text[i..]).1 { Some(i) } else { None }
 }
 
 // returned pair is (number of bytes, number of spaces)
@@ -533,7 +569,7 @@ pub fn scan_listitem(data: &str) -> (usize, u8, usize, usize) {
         postn = 1;
         postindent = 1;
     }
-    if let Some(_) = scan_blank_line(&data[w..]) {
+    if scan_blank_line(&data[w..]).is_some() {
         postn = 0;
         postindent = 1;
     }
@@ -670,12 +706,12 @@ pub fn scan_attribute_value(data: &str) -> Option<usize> {
         }
     }
     if i >= data.len() { return None; }
-    return Some(i);
+    Some(i)
 
 }
 
 // Remove backslash escapes and resolve entities
-pub fn unescape<'a>(input: &'a str) -> CowStr<'a> {
+pub fn unescape(input: &str) -> CowStr<'_> {
     let mut result = String::new();
     let mut mark = 0;
     let mut i = 0;
@@ -775,11 +811,7 @@ pub fn scan_html_type_7(data: &str) -> Option<usize> {
     }
     i += c;
 
-    if let Some(_) = scan_blank_line(&data[i..]) {
-        return Some(i);
-    } else {
-        return None;
-    }
+    scan_blank_line(&data[i..]).map(|_| i)
 }
 
 pub fn scan_attribute(data: &str) -> Option<usize> {
@@ -789,12 +821,7 @@ pub fn scan_attribute(data: &str) -> Option<usize> {
     } else {
         return None;
     }
-    if let Some(attr_valspec_bytes) = scan_attribute_value_spec(&data[i..]) {
-        i += attr_valspec_bytes;
-    } else {
-        return None;
-    }
-    return Some(i);
+    scan_attribute_value_spec(&data[i..]).map(|attr_valspec_bytes| attr_valspec_bytes + i)
 }
 
 pub fn scan_attribute_value_spec(data: &str) -> Option<usize> {
